@@ -17,7 +17,6 @@
              
     to purchase a commercial license.
 """
-from collections import defaultdict
 
 
 class tree(dict):
@@ -28,5 +27,3 @@ class tree(dict):
         except KeyError:
             value = self[item] = type(self)()
             return value
-
-# def tree(): return defaultdict(tree)
