@@ -170,7 +170,7 @@ class Experiment:
         self.event_handler = ExperimentEventHandler()
         self.observer = Observer()
         self.snap_member = []
-
+        self.expparam = exp
         self.keycode(sys.modules["__main__"])
         atexit.register(self.end_exp)
         # self.exithook = gu.exithook()
@@ -200,7 +200,7 @@ class Experiment:
 
     def start_exp(self):
         self.observer.start()
-        for member in self.snap_member:
+        for member in self.expparam.snap_member:
             if inspect.ismodule(member):
                 if not getattr(member, '__file__', None):
                     warnings.warn('{!r} is a built-in module'.format(member))
@@ -255,6 +255,18 @@ class Experiment:
         with open(path, "w", encoding="utf-8") as w:
             w.write(code)
 
+    def keycode(self, member=None):
+        return self.expparam.keycode(member)
+
+    def summary(self):
+        pp.pprint(self.exp_info)
+        pp.pprint(self.expparam)
+
+class ExpParam:
+    def __init__(self):
+        self.snap_member = []
+        self.params = {}
+
     def keycode(self, member=None):
         if member is not None:
             self.snap_member.append(member)
@@ -266,15 +278,17 @@ class Experiment:
 
         return func
 
-    def summary(self):
-        pp.pprint(self.exp_info)
+    def __getitem__(self, item):
+        return self.params[item]
 
-    def __getattr__(self, item):
-        return self.glob[item]
+    def __setitem__(self, key, value):
+        self.params[key] = value
+
+exp = ExpParam()
 
 
 class ExperimentEventHandler(FileSystemEventHandler):
-    """用来获取试验过程中的模型保存和日志输出的变化 TODO """
+    """用来获取试验过程中的模型保存和日志输出的变化 """
 
     def __init__(self):
         self.file_dict = tree()
